summaryrefslogtreecommitdiff
path: root/include/canvas
diff options
context:
space:
mode:
Diffstat (limited to 'include/canvas')
-rw-r--r--include/canvas/base/canvascustomspritehelper.hxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/include/canvas/base/canvascustomspritehelper.hxx b/include/canvas/base/canvascustomspritehelper.hxx
index f0a3fde38fb4..f44f5213b1e7 100644
--- a/include/canvas/base/canvascustomspritehelper.hxx
+++ b/include/canvas/base/canvascustomspritehelper.hxx
@@ -208,7 +208,7 @@ namespace canvas
This method recomputes the maCurrClipBounds and
mbIsCurrClipRectangle members from the current clip and
- transformation. If the clip changed from rectangular to
+ transformation. IFF the clip changed from rectangular to
rectangular again, this method issues a sequence of
optimized SpriteSurface::updateSprite() calls.
@@ -258,22 +258,22 @@ namespace canvas
*/
mutable bool mbIsContentFullyOpaque;
/// True, if mfAlpha has changed
mutable bool mbAlphaDirty;
/// True, if maPosition has changed
mutable bool mbPositionDirty;
/// True, if maTransform has changed
mutable bool mbTransformDirty;
/// True, if mxClipPoly has changed
mutable bool mbClipDirty;
/// True, if mnPriority has changed
mutable bool mbPrioDirty;
/// True, if mbActive has changed
mutable bool mbVisibilityDirty;
};
}
@@ -258,22 +258,22 @@ namespace canvas
*/
mutable bool mbIsContentFullyOpaque;
- /// True, if mfAlpha has changed
+ /// True, iff mfAlpha has changed
mutable bool mbAlphaDirty;
@@ -258,22 +258,22 @@ namespace canvas
mutable bool mbAlphaDirty;
- /// True, if maPosition has changed
+ /// True, iff maPosition has changed
mutable bool mbPositionDirty;
@@ -258,22 +258,22 @@ namespace canvas
mutable bool mbPositionDirty;
- /// True, if maTransform has changed
+ /// True, iff maTransform has changed
mutable bool mbTransformDirty;
@@ -258,22 +258,22 @@ namespace canvas
mutable bool mbTransformDirty;
- /// True, if mxClipPoly has changed
+ /// True, iff mxClipPoly has changed
mutable bool mbClipDirty;
@@ -258,22 +258,22 @@ namespace canvas
mutable bool mbClipDirty;
- /// True, if mnPriority has changed
+ /// True, iff mnPriority has changed
mutable bool mbPrioDirty;
@@ -258,22 +258,22 @@ namespace canvas
mutable bool mbPrioDirty;
- /// True, if mbActive has changed
+ /// True, iff mbActive has changed
mutable bool mbVisibilityDirty;
};